@@ -20,7 +20,7 @@ import logging
 import click
 import consolemd
 
-from substra import __version__, runner
+from substra import __version__
 from substra.cli import printers
 from substra.sdk import assets, exceptions, utils
 from substra.sdk import config as configuration
@@ -1064,101 +1064,6 @@ def leaderboard(ctx, expand, objective_key, sort):
     printer.print(board, expand=expand)
 
 
-@cli.command()
-@click.argument('algo',
-                type=click.Path(exists=True))
-@click.option('--train-opener',
-              type=click.Path(exists=True, dir_okay=False),
-              required=True,
-              help='opener.py file to use during training.')
-@click.option('--test-opener',
-              type=click.Path(exists=True, dir_okay=False),
-              required=True,
-              help='opener.py file to use during testing.')
-@click.option('--metrics',
-              type=click.Path(exists=True),
-              required=True,
-              help='metrics directory or archive to use during both training and testing.')
-@click.option('--rank',
-              type=click.INT,
-              default=0,
-              help='will be passed to the algo during training.')
-@click.option('--train-data-samples',
-              type=click.Path(exists=True, file_okay=False),
-              help='directory of data samples directories to use during training.')
-@click.option('--test-data-samples',
-              type=click.Path(exists=True, file_okay=False),
-              help='directory of data samples directories to use during testing.')
-@click.option('--inmodel', 'inmodels',
-              type=click.Path(exists=True, dir_okay=False),
-              multiple=True,
-              help='model to use as input during training.')
-@click.option('--fake-data-samples',
-              is_flag=True,
-              help='use fake data samples during both training and testing.')
-@click.option('--n-fake-samples',
-              type=click.INT,
-              help='Number of fake data samples requested')
-def run_local(algo, train_opener, test_opener, metrics, rank,
-              train_data_samples, test_data_samples, inmodels,
-              fake_data_samples, n_fake_samples):
-    """Run local.
-
-    Train and test the algo located in ALGO (directory or archive) locally.
-
-    This command can be used to check that objective, dataset and algo assets
-    implementations are compatible.
-
-    It will execute sequentially 3 tasks in docker:
-
-    \b
-    - train algo using train data samples
-    - test model using test data samples
-    - get model perf
-
-    \b
-    It will create several output files:
-    - sandbox/model/model
-    - sandbox/pred_test/perf.json
-    - sandbox/pred_test/pred
-    """
-    if fake_data_samples and (train_data_samples or test_data_samples):
-        raise click.BadOptionUsage('--fake-data-samples',
-                                   'Options --train-data-samples and --test-data-samples cannot '
-                                   'be used if --fake-data-samples is activated')
-    if not fake_data_samples and not train_data_samples and not test_data_samples:
-        raise click.BadOptionUsage('--fake-data-samples',
-                                   'Missing option --fake-data-samples or --test-data-samples '
-                                   'and --train-data-samples')
-    if not fake_data_samples and train_data_samples and not test_data_samples:
-        raise click.BadOptionUsage('--test-data-samples',
-                                   'Missing option --test-data-samples')
-    if not fake_data_samples and not train_data_samples and test_data_samples:
-        raise click.BadOptionUsage('--train-data-samples',
-                                   'Missing option --train-data-samples')
-    if not fake_data_samples and n_fake_samples:
-        raise click.BadOptionUsage('--n-fake-samples',
-                                   'Option --n-fake-samples cannot be used if'
-                                   '--fake-data-samples is not activated')
-
-    try:
-        runner.compute(algo_path=algo,
-                       train_opener_file=train_opener,
-                       test_opener_file=test_opener,
-                       metrics_path=metrics,
-                       train_data_path=train_data_samples,
-                       test_data_path=test_data_samples,
-                       fake_data_samples=fake_data_samples,
-                       rank=rank,
-                       inmodels=inmodels,
-                       n_fake_samples=n_fake_samples)
-    except runner.PathTraversalException as e:
-        raise click.ClickException(
-            f'Archive "{e.archive_path}" includes at least 1 file or folder '
-            f'located outside the archive root folder: "{e.issue_path}"'
-        )
-
-
 @cli.group()
 @click.pass_context
 def cancel(ctx):
@@ -1167,14 +1072,14 @@ def cancel(ctx):
 
 
 @cancel.command('compute_plan')
-@click.argument('compute_plan_id', type=click.STRING)
+@click.argument('compute_plan_key', type=click.STRING)
 @click_global_conf_with_output_format
 @click.pass_context
-def cancel_compute_plan(ctx, compute_plan_id):
+def cancel_compute_plan(ctx, compute_plan_key):
     """Cancel execution of a compute plan."""
     client = get_client(ctx.obj)
     # method must exist in sdk
-    res = client.cancel_compute_plan(compute_plan_id)
+    res = client.cancel_compute_plan(compute_plan_key)
     printer = printers.get_asset_printer(assets.COMPUTE_PLAN, ctx.obj.output_format)
     printer.print(res, profile=ctx.obj.profile)
 
@@ -1228,7 +1133,7 @@ def update_dataset(ctx, dataset_key, objective_key):
 
 
 @update.command('compute_plan')
-@click.argument('compute_plan_id', type=click.STRING)
+@click.argument('compute_plan_key', type=click.STRING)
 @click.argument('tuples', type=click.Path(exists=True, dir_okay=False),
                 callback=load_json_from_path, metavar="TUPLES_PATH")
 @click.option('--no-auto-batching', '-n', is_flag=True,
@@ -1239,7 +1144,7 @@ def update_dataset(ctx, dataset_key, objective_key):
 @click_global_conf_with_output_format
 @click.pass_context
 @error_printer
-def update_compute_plan(ctx, compute_plan_id, tuples, no_auto_batching, batch_size):
+def update_compute_plan(ctx, compute_plan_key, tuples, no_auto_batching, batch_size):
     """Update compute plan.
 
     The tuples path must point to a valid JSON file with the following schema:
@@ -1296,7 +1201,7 @@ def update_compute_plan(ctx, compute_plan_id, tuples, no_auto_batching, batch_si
                                    "The --batch_size option cannot be used when using "
                                    "--no_auto_batching.")
     client = get_client(ctx.obj)
-    res = client.update_compute_plan(compute_plan_id, tuples, not no_auto_batching, batch_size)
+    res = client.update_compute_plan(compute_plan_key, tuples, not no_auto_batching, batch_size)
     printer = printers.get_asset_printer(assets.COMPUTE_PLAN, ctx.obj.output_format)
     printer.print(res, is_list=False)
 
