@@ -11,9 +11,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import os
+from pathlib import Path
 import shutil
 import typing
 import warnings
+from distutils import util
 
 import substra
 from substra.sdk import schemas, models, exceptions, fs, graph, compute_plan as compute_plan_module
@@ -24,13 +27,22 @@ from substra.sdk.backends.local import compute
 _BACKEND_ID = "local-backend"
 _MAX_LEN_KEY_METADATA = 50
 _MAX_LEN_VALUE_METADATA = 100
+DEBUG_OWNER = "debug_owner"
 
 
 class Local(base.BaseBackend):
     def __init__(self, backend, *args, **kwargs):
+        self._support_chainkeys = bool(util.strtobool(os.getenv("CHAINKEYS_ENABLED", 'False')))
+        self._chainkey_dir = Path(os.getenv("CHAINKEYS_DIR", Path.home() / ".substra_chainkeys"))
+        if self._support_chainkeys:
+            print(f"Chainkeys support is on, the directory is {self._chainkey_dir}")
         # create a store to abstract the db
         self._db = dal.DataAccess(backend)
-        self._worker = compute.Worker(self._db)
+        self._worker = compute.Worker(
+            self._db,
+            support_chainkeys=self._support_chainkeys,
+            chainkey_dir=self._chainkey_dir
+        )
 
     @property
     def temp_directory(self):
@@ -79,7 +91,7 @@ class Local(base.BaseBackend):
         return result
 
     @staticmethod
-    def __check_metadata(metadata: typing.Optional[typing.Dict[str, str]]):
+    def _check_metadata(metadata: typing.Optional[typing.Dict[str, str]]):
         if metadata is not None:
             if any([len(key) > _MAX_LEN_KEY_METADATA for key in metadata]):
                 raise exceptions.InvalidRequest(
@@ -95,8 +107,15 @@ class Local(base.BaseBackend):
                     400
                 )
 
+        # In debug mode, the user can define the owner of the data
+        if metadata is not None and DEBUG_OWNER in metadata:
+            owner = metadata[DEBUG_OWNER]
+        else:
+            owner = _BACKEND_ID
+        return owner
+
     @staticmethod
-    def __compute_permissions(permissions):
+    def __compute_permissions(permissions, owner=_BACKEND_ID):
         """Compute the permissions
 
         If the permissions are private, the active node is
@@ -104,8 +123,8 @@ class Local(base.BaseBackend):
         """
         if permissions.public:
             permissions.authorized_ids = list()
-        elif not permissions.public and _BACKEND_ID not in permissions.authorized_ids:
-            permissions.authorized_ids.append(_BACKEND_ID)
+        elif not permissions.public and owner not in permissions.authorized_ids:
+            permissions.authorized_ids.append(owner)
         return permissions
 
     def __add_compute_plan(
@@ -123,9 +142,9 @@ class Local(base.BaseBackend):
                 testtuple_keys or list(),
             ]
         ])
-        compute_plan_id = self._db.get_local_key(schemas.ComputePlanSpec.compute_key())
+        key = self._db.get_local_key(schemas._Spec.compute_key())
         compute_plan = models.ComputePlan(
-            compute_plan_id=compute_plan_id,
+            key=key,
             status=models.Status.waiting,
             traintuple_keys=traintuple_keys,
             composite_traintuple_keys=composite_traintuple_keys,
@@ -141,18 +160,18 @@ class Local(base.BaseBackend):
 
     def __create_compute_plan_from_tuple(self, spec, key, in_tuples):
         # compute plan and rank
-        if not spec.compute_plan_id and spec.rank == 0:
+        if not spec.compute_plan_key and spec.rank == 0:
             #  Create a compute plan
             compute_plan = self.__add_compute_plan(traintuple_keys=[key])
             rank = 0
-            compute_plan_id = compute_plan.compute_plan_id
-        elif not spec.compute_plan_id and spec.rank is not None:
+            compute_plan_key = compute_plan.key
+        elif not spec.compute_plan_key and spec.rank is not None:
             raise substra.sdk.exceptions.InvalidRequest(
                 "invalid inputs, a new ComputePlan should have a rank 0", 400
             )
-        elif spec.compute_plan_id:
-            compute_plan = self._db.get(schemas.Type.ComputePlan, spec.compute_plan_id)
-            compute_plan_id = compute_plan.compute_plan_id
+        elif spec.compute_plan_key:
+            compute_plan = self._db.get(schemas.Type.ComputePlan, spec.compute_plan_key)
+            compute_plan_key = compute_plan.key
             if spec.rank is not None:
                 # Use the rank given by the user
                 rank = spec.rank
@@ -164,7 +183,7 @@ class Local(base.BaseBackend):
                         [
                             in_tuple.rank
                             for in_tuple in in_tuples
-                            if in_tuple.compute_plan_id == compute_plan_id
+                            if in_tuple.compute_plan_key == compute_plan_key
                         ]
                     )
 
@@ -179,13 +198,13 @@ class Local(base.BaseBackend):
             compute_plan.status = models.Status.waiting
 
         else:
-            compute_plan_id = ""
+            compute_plan_key = ""
             rank = 0
 
-        return compute_plan_id, rank
+        return compute_plan_key, rank
 
     def __get_id_rank_in_compute_plan(self, type_, key, id_to_key):
-        tuple_ = self._db.get(schemas.Type.Traintuple, key)
+        tuple_ = self._db.get(type_, key)
         id_ = next((k for k in id_to_key if id_to_key[k] == key), None)
         return id_, tuple_.rank
 
@@ -199,31 +218,28 @@ class Local(base.BaseBackend):
                 compositetuples,
                 spec_options
             ):
-        # The tasks in the compute plan cannot already exist
-        exist_ok = False
         for id_, rank in sorted(visited.items(), key=lambda item: item[1]):
             if id_ in traintuples:
                 traintuple = traintuples[id_]
                 traintuple_spec = schemas.TraintupleSpec.from_compute_plan(
-                    compute_plan_id=compute_plan.compute_plan_id,
+                    compute_plan_key=compute_plan.key,
                     id_to_key=compute_plan.id_to_key,
                     rank=rank,
                     spec=traintuple
                 )
-                traintuple_key = self.add(traintuple_spec, exist_ok, spec_options)
+                traintuple_key = self.add(traintuple_spec, spec_options)
                 compute_plan.id_to_key[id_] = traintuple_key
 
             elif id_ in aggregatetuples:
                 aggregatetuple = aggregatetuples[id_]
                 aggregatetuple_spec = schemas.AggregatetupleSpec.from_compute_plan(
-                    compute_plan_id=compute_plan.compute_plan_id,
+                    compute_plan_key=compute_plan.key,
                     id_to_key=compute_plan.id_to_key,
                     rank=rank,
                     spec=aggregatetuple
                 )
                 aggregatetuple_key = self.add(
                     aggregatetuple_spec,
-                    exist_ok,
                     spec_options,
                 )
                 compute_plan.id_to_key[id_] = aggregatetuple_key
@@ -231,14 +247,13 @@ class Local(base.BaseBackend):
             elif id_ in compositetuples:
                 compositetuple = compositetuples[id_]
                 compositetuple_spec = schemas.CompositeTraintupleSpec.from_compute_plan(
-                    compute_plan_id=compute_plan.compute_plan_id,
+                    compute_plan_key=compute_plan.key,
                     id_to_key=compute_plan.id_to_key,
                     rank=rank,
                     spec=compositetuple
                 )
                 compositetuple_key = self.add(
                     compositetuple_spec,
-                    exist_ok,
                     spec_options,
                 )
                 compute_plan.id_to_key[id_] = compositetuple_key
@@ -249,7 +264,7 @@ class Local(base.BaseBackend):
                     id_to_key=compute_plan.id_to_key,
                     spec=testtuple
                 )
-                self.add(testtuple_spec, exist_ok, spec_options)
+                self.add(testtuple_spec, spec_options)
 
         return compute_plan
 
@@ -258,7 +273,8 @@ class Local(base.BaseBackend):
         algo = self._db.get(traintuple.algo_type, traintuple.algo.key)
         return {
             'algo': {
-                'hash': algo.key,
+                'key': algo.key,
+                'checksum': algo.content.checksum,
                 'name': algo.name,
                 'storage_address': str(algo.content.storage_address)
             },
@@ -286,15 +302,15 @@ class Local(base.BaseBackend):
                     "dataSample do not belong to the same dataManager", 400
                 )
 
-    def __add_algo(self, model_class, key, spec, spec_options=None):
+    def __add_algo(self, model_class, key, spec, owner, spec_options=None):
 
-        permissions = self.__compute_permissions(spec.permissions)
+        permissions = self.__compute_permissions(spec.permissions, owner)
         algo_file_path = self._db.save_file(spec.file, key)
         algo_description_path = self._db.save_file(spec.description, key)
         algo = model_class(
             key=key,
             name=spec.name,
-            owner=_BACKEND_ID,
+            owner=owner,
             permissions={
                 "process": {
                     "public": permissions.public,
@@ -302,11 +318,11 @@ class Local(base.BaseBackend):
                 },
             },
             content={
-                "hash": key,
+                "checksum": fs.hash_file(algo_file_path),
                 "storage_address": algo_file_path
             },
             description={
-                "hash": self._db.get_local_key(fs.hash_file(algo_description_path)),
+                "checksum": fs.hash_file(algo_description_path),
                 "storage_address": algo_description_path
             },
             metadata=spec.metadata if spec.metadata else dict(),
@@ -314,31 +330,32 @@ class Local(base.BaseBackend):
         return self._db.add(algo)
 
     def _add_algo(self, key, spec, spec_options=None):
-        self.__check_metadata(spec.metadata)
-        return self.__add_algo(models.Algo, key, spec, spec_options=spec_options)
+        owner = self._check_metadata(spec.metadata)
+        return self.__add_algo(models.Algo, key, spec, owner, spec_options=spec_options)
 
     def _add_aggregate_algo(self, key, spec, spec_options=None):
-        self.__check_metadata(spec.metadata)
+        owner = self._check_metadata(spec.metadata)
         return self.__add_algo(
-            models.AggregateAlgo, key, spec, spec_options=spec_options
+            models.AggregateAlgo, key, spec, owner, spec_options=spec_options
         )
 
     def _add_composite_algo(self, key, spec, spec_options=None):
-        self.__check_metadata(spec.metadata)
+        owner = self._check_metadata(spec.metadata)
         return self.__add_algo(
-            models.CompositeAlgo, key, spec, spec_options=spec_options
+            models.CompositeAlgo, key, spec, owner, spec_options=spec_options
         )
 
     def _add_dataset(self, key, spec, spec_options=None):
 
-        self.__check_metadata(spec.metadata)
-        permissions = self.__compute_permissions(spec.permissions)
+        owner = self._check_metadata(spec.metadata)
+
+        permissions = self.__compute_permissions(spec.permissions, owner)
 
         dataset_file_path = self._db.save_file(spec.data_opener, key)
         dataset_description_path = self._db.save_file(spec.description, key)
         asset = models.Dataset(
             key=key,
-            owner=_BACKEND_ID,
+            owner=owner,
             name=spec.name,
             objective_key=spec.objective_key if spec.objective_key else "",
             permissions={
@@ -351,11 +368,11 @@ class Local(base.BaseBackend):
             train_data_sample_keys=list(),
             test_data_sample_keys=list(),
             opener={
-                "hash": key,
+                "checksum": fs.hash_file(dataset_file_path),
                 "storage_address": dataset_file_path
             },
             description={
-                "hash": self._db.get_local_key(fs.hash_file(dataset_description_path)),
+                "checksum": fs.hash_file(dataset_description_path),
                 "storage_address": dataset_description_path
             },
             metadata=spec.metadata if spec.metadata else dict(),
@@ -413,8 +430,8 @@ class Local(base.BaseBackend):
 
     def _add_objective(self, key, spec, spec_options):
 
-        self.__check_metadata(spec.metadata)
-        permissions = self.__compute_permissions(spec.permissions)
+        owner = self._check_metadata(spec.metadata)
+        permissions = self.__compute_permissions(spec.permissions, owner)
 
         # validate spec
         test_dataset = None
@@ -428,7 +445,8 @@ class Local(base.BaseBackend):
             test_dataset = {
                 "data_manager_key": spec.test_data_manager_key,
                 "data_sample_keys": spec.test_data_sample_keys,
-                "metadata": dataset.metadata
+                "metadata": dataset.metadata,
+                "worker": dataset.owner,
             }
             if not dataset.objective_key:
                 dataset.objective_key = key
@@ -445,7 +463,7 @@ class Local(base.BaseBackend):
         objective = models.Objective(
             key=key,
             name=spec.name,
-            owner=_BACKEND_ID,
+            owner=owner,
             test_dataset=test_dataset,
             permissions={
                 "process": {
@@ -454,12 +472,12 @@ class Local(base.BaseBackend):
                 },
             },
             description={
-                "hash": self._db.get_local_key(fs.hash_file(objective_description_path)),
+                "checksum": fs.hash_file(objective_description_path),
                 "storage_address": objective_description_path
             },
             metrics={
                 "name": spec.metrics_name,
-                "hash": self._db.get_local_key(fs.hash_file(objective_file_path)),
+                "checksum": fs.hash_file(objective_file_path),
                 "storage_address": objective_file_path
             },
             metadata=spec.metadata if spec.metadata else dict(),
@@ -480,7 +498,7 @@ class Local(base.BaseBackend):
             warnings.warn(
                 "'clean_models=True' is not supported on the local backend."
             )
-        self.__check_metadata(spec.metadata)
+        self._check_metadata(spec.metadata)
         # Get all the tuples and their dependencies
         (
             tuple_graph,
@@ -493,7 +511,7 @@ class Local(base.BaseBackend):
         visited = graph.compute_ranks(node_graph=tuple_graph)
 
         compute_plan = models.ComputePlan(
-            compute_plan_id=key,
+            key=key,
             tag=spec.tag or "",
             status=models.Status.waiting,
             metadata=spec.metadata or dict(),
@@ -517,7 +535,7 @@ class Local(base.BaseBackend):
 
     def _add_traintuple(self, key, spec, spec_options=None):
         # validation
-        self.__check_metadata(spec.metadata)
+        owner = self._check_metadata(spec.metadata)
         algo = self._db.get(schemas.Type.Algo, spec.algo_key)
         data_manager = self._db.get(schemas.Type.Dataset, spec.data_manager_key)
         in_traintuples = (
@@ -547,7 +565,7 @@ class Local(base.BaseBackend):
             authorized_ids = list(authorized_ids)
 
         # compute plan and rank
-        compute_plan_id, rank = self.__create_compute_plan_from_tuple(
+        compute_plan_key, rank = self.__create_compute_plan_from_tuple(
             spec=spec,
             key=key,
             in_tuples=in_traintuples
@@ -557,29 +575,32 @@ class Local(base.BaseBackend):
         options = {}
         traintuple = models.Traintuple(
             key=key,
-            creator=_BACKEND_ID,
+            creator=owner,
             algo={
-                "hash": spec.algo_key,
+                "key": spec.algo_key,
+                "checksum": algo.content.checksum,
                 "name": algo.name,
                 "storage_address": algo.content.storage_address
             },
             dataset={
-                "opener_hash": spec.data_manager_key,
-                "keys": spec.train_data_sample_keys,
-                "worker": _BACKEND_ID,
+                "key": spec.data_manager_key,
+                "opener_checksum": data_manager.opener.checksum,
+                "data_sample_keys": spec.train_data_sample_keys,
+                "worker": data_manager.owner,
                 "metadata": {}
             },
             permissions={
                 "process": {"public": public, "authorized_ids": authorized_ids},
             },
             log="",
-            compute_plan_id=compute_plan_id,
+            compute_plan_key=compute_plan_key,
             rank=rank,
             tag=spec.tag or "",
             status=models.Status.waiting,
             in_models=[
                 {
-                    "hash": in_traintuple.out_model.hash_,
+                    "key": in_traintuple.out_model.key,
+                    "checksum": in_traintuple.out_model.checksum,
                     "storage_address": in_traintuple.out_model.storage_address,
                     "traintuple_key": in_traintuple.key,
                 }
@@ -596,7 +617,7 @@ class Local(base.BaseBackend):
     def _add_testtuple(self, key, spec, spec_options=None):
 
         # validation
-        self.__check_metadata(spec.metadata)
+        owner = self._check_metadata(spec.metadata)
         objective = self._db.get(schemas.Type.Objective, spec.objective_key)
 
         traintuple = None
@@ -606,7 +627,7 @@ class Local(base.BaseBackend):
                 schemas.Type.Aggregatetuple
         ]:
             try:
-                traintuple = self._db.get(tuple_type, spec.traintuple_key)
+                traintuple = self._db.get(tuple_type, spec.traintuple_key, log=False)
                 break
             except exceptions.NotFound:
                 pass
@@ -631,7 +652,7 @@ class Local(base.BaseBackend):
                 spec.test_data_sample_keys is not None
                 and len(spec.test_data_sample_keys) > 0
             )
-            dataset_opener = spec.data_manager_key
+            dataset_key = spec.data_manager_key
             test_data_sample_keys = spec.test_data_sample_keys
             certified = (
                 objective.test_dataset is not None
@@ -643,13 +664,15 @@ class Local(base.BaseBackend):
             assert (
                 objective.test_dataset
             ), "can not create a certified testtuple, no data associated with objective"
-            dataset_opener = objective.test_dataset.data_manager_key
+            dataset_key = objective.test_dataset.data_manager_key
             test_data_sample_keys = objective.test_dataset.data_sample_keys
             certified = True
 
-        if traintuple.compute_plan_id:
+        dataset = self._db.get(schemas.Type.Dataset, dataset_key)
+
+        if traintuple.compute_plan_key:
             compute_plan = self._db.get(
-                schemas.Type.ComputePlan, traintuple.compute_plan_id
+                schemas.Type.ComputePlan, traintuple.compute_plan_key
             )
             if compute_plan.testtuple_keys is None:
                 compute_plan.testtuple_keys = [key]
@@ -661,9 +684,9 @@ class Local(base.BaseBackend):
         options = {}
         testtuple = models.Testtuple(
             key=key,
-            creator=_BACKEND_ID,
+            creator=owner,
             objective={
-                "hash": spec.objective_key,
+                "key": spec.objective_key,
                 "metrics": objective.metrics
             },
             traintuple_key=spec.traintuple_key,
@@ -671,16 +694,17 @@ class Local(base.BaseBackend):
             algo=traintuple.algo,
             certified=certified,
             dataset={
-                "opener_hash": dataset_opener,
+                "key": dataset_key,
+                "opener_checksum": dataset.opener.checksum,
                 "perf": -1,
-                "keys": test_data_sample_keys,
-                "worker": _BACKEND_ID,
+                "data_sample_keys": test_data_sample_keys,
+                "worker": dataset.owner,
             },
             log="",
             tag=spec.tag or "",
             status=models.Status.waiting,
             rank=traintuple.rank,
-            compute_plan_id=traintuple.compute_plan_id,
+            compute_plan_key=traintuple.compute_plan_key,
             metadata=spec.metadata if spec.metadata else dict(),
             **options,
         )
@@ -695,9 +719,9 @@ class Local(base.BaseBackend):
         spec_options=None
     ):
         # validation
-        self.__check_metadata(spec.metadata)
+        owner = self._check_metadata(spec.metadata)
         algo = self._db.get(schemas.Type.CompositeAlgo, spec.algo_key)
-        self._db.get(schemas.Type.Dataset, spec.data_manager_key)
+        dataset = self._db.get(schemas.Type.Dataset, spec.data_manager_key)
         self.__check_same_data_manager(spec.data_manager_key, spec.train_data_sample_keys)
 
         in_head_model = None
@@ -708,7 +732,8 @@ class Local(base.BaseBackend):
             in_head_tuple = self._db.get(schemas.Type.CompositeTraintuple, spec.in_head_model_key)
             assert in_head_tuple.out_head_model
             in_head_model = models.InHeadModel(
-                hash=in_head_tuple.out_head_model.out_model.hash_,
+                key=in_head_tuple.out_head_model.out_model.key,
+                checksum=in_head_tuple.out_head_model.out_model.checksum,
                 storage_address=in_head_tuple.out_head_model.out_model.storage_address
             )
             in_tuples.append(in_head_tuple)
@@ -717,7 +742,7 @@ class Local(base.BaseBackend):
             try:
                 # in trunk model is a composite traintuple out trunk model
                 in_trunk_tuple = self._db.get(
-                    schemas.Type.CompositeTraintuple, spec.in_trunk_model_key
+                    schemas.Type.CompositeTraintuple, spec.in_trunk_model_key, log=False
                 )
                 assert in_trunk_tuple.out_trunk_model
                 in_model = in_trunk_tuple.out_trunk_model.out_model
@@ -728,13 +753,14 @@ class Local(base.BaseBackend):
                 in_model = in_trunk_tuple.out_model
 
             in_trunk_model = models.InModel(
-                hash=in_model.hash_,
+                key=in_model.key,
+                checksum=in_model.checksum,
                 storage_address=in_model.storage_address
             )
             in_tuples.append(in_trunk_tuple)
 
         # Compute plan
-        compute_plan_id, rank = self.__create_compute_plan_from_tuple(spec, key, in_tuples)
+        compute_plan_key, rank = self.__create_compute_plan_from_tuple(spec, key, in_tuples)
 
         # permissions
         trunk_model_permissions = schemas.Permissions(
@@ -749,25 +775,27 @@ class Local(base.BaseBackend):
             head_model_permissions = {
                 "process": {
                     "public": False,
-                    "authorized_ids": [_BACKEND_ID]
+                    "authorized_ids": [owner]
                 }
             }
 
         composite_traintuple = models.CompositeTraintuple(
             key=key,
-            creator=_BACKEND_ID,
+            creator=owner,
             algo={
-                "hash": spec.algo_key,
+                "key": spec.algo_key,
+                "checksum": algo.content.checksum,
                 "name": algo.name,
                 "storage_address": algo.content.storage_address
             },
             dataset={
-                "opener_hash": spec.data_manager_key,
-                "keys": spec.train_data_sample_keys,
-                "worker": _BACKEND_ID,
+                "key": spec.data_manager_key,
+                "opener_checksum": dataset.opener.checksum,
+                "data_sample_keys": spec.train_data_sample_keys,
+                "worker": dataset.owner,
             },
             tag=spec.tag or '',
-            compute_plan_id=compute_plan_id,
+            compute_plan_key=compute_plan_key,
             rank=rank,
             status=models.Status.waiting,
             log='',
@@ -796,16 +824,17 @@ class Local(base.BaseBackend):
                             spec_options: dict = None,
                             ):
         # validation
-        self.__check_metadata(spec.metadata)
+        owner = self._check_metadata(spec.metadata)
         algo = self._db.get(schemas.Type.AggregateAlgo, spec.algo_key)
         in_tuples = list()
         in_models = list()
         in_permissions = list()
         for model_key in spec.in_models_keys:
             try:
-                in_tuple = self._db.get(schemas.Type.Traintuple, key=model_key)
+                in_tuple = self._db.get(schemas.Type.Traintuple, key=model_key, log=False)
                 in_models.append({
-                    "hash": in_tuple.out_model.hash_,
+                    "key": in_tuple.out_model.key,
+                    "checksum": in_tuple.out_model.checksum,
                     "storage_address": in_tuple.out_model.storage_address,
                     "traintuple_key": in_tuple.key,
                 })
@@ -813,15 +842,16 @@ class Local(base.BaseBackend):
             except exceptions.NotFound:
                 in_tuple = self._db.get(schemas.Type.CompositeTraintuple, key=model_key)
                 in_models.append({
-                    "hash": in_tuple.out_head_model.out_model.hash_,
-                    "storage_address": in_tuple.out_head_model.out_model.storage_address,
+                    "key": in_tuple.out_trunk_model.out_model.key,
+                    "checksum": in_tuple.out_trunk_model.out_model.checksum,
+                    "storage_address": in_tuple.out_trunk_model.out_model.storage_address,
                     "traintuple_key": in_tuple.key,
                 })
-                in_permissions.append(in_tuple.out_head_model.permissions.process)
+                in_permissions.append(in_tuple.out_trunk_model.permissions.process)
             in_tuples.append(in_tuple)
 
         # Compute plan
-        compute_plan_id, rank = self.__create_compute_plan_from_tuple(spec, key, in_tuples)
+        compute_plan_key, rank = self.__create_compute_plan_from_tuple(spec, key, in_tuples)
 
         # Permissions
         public = False
@@ -834,10 +864,11 @@ class Local(base.BaseBackend):
 
         aggregatetuple = models.Aggregatetuple(
             key=key,
-            creator=_BACKEND_ID,
+            creator=owner,
             worker=spec.worker,
             algo={
-                "hash": spec.algo_key,
+                "key": spec.algo_key,
+                "checksum": algo.content.checksum,
                 "name": algo.name,
                 "storage_address": algo.content.storage_address
             },
@@ -848,7 +879,7 @@ class Local(base.BaseBackend):
                 }
             },
             tag=spec.tag or '',
-            compute_plan_id=compute_plan_id,
+            compute_plan_key=compute_plan_key,
             rank=rank,
             status=models.Status.waiting,
             log='',
@@ -861,27 +892,17 @@ class Local(base.BaseBackend):
             self._worker.schedule_traintuple(aggregatetuple)
         return aggregatetuple
 
-    def add(self, spec, exist_ok=False, spec_options=None):
+    def add(self, spec, spec_options=None):
         # find dynamically the method to call to create the asset
         method_name = f"_add_{spec.__class__.type_.value}"
         if spec.is_many():
             method_name += "s"
         add_asset = getattr(self, method_name)
         if spec.is_many():
-            # 'exist_ok' is not supported
             assets = add_asset(spec, spec_options)
             return [asset.key for asset in assets]
         else:
-            # Check if the asset exists, return it if 'exist_ok' is True
             key = self._db.get_local_key(spec.compute_key())
-            try:
-                asset = self._db.get(type_=spec.__class__.type_, key=key, log=False)
-            except exceptions.NotFound:
-                pass
-            else:
-                if exist_ok:
-                    return key
-                raise exceptions.AlreadyExists(key, 409)
             asset = add_asset(key, spec, spec_options)
             if spec.__class__.type_ == schemas.Type.ComputePlan:
                 return asset
@@ -940,7 +961,7 @@ class Local(base.BaseBackend):
 
     def leaderboard(self, objective_key, sort='desc'):
         objective = self._db.get(schemas.Type.Objective, objective_key)
-        testtuples = self._db.list(schemas.Type.Testtuple)
+        testtuples = self._db.list(schemas.Type.Testtuple, filters=None)
         certified_testtuples = [
             self.__format_for_leaderboard(t)
             for t in testtuples
@@ -953,16 +974,16 @@ class Local(base.BaseBackend):
         }
         return board
 
-    def cancel_compute_plan(self, compute_plan_id):
+    def cancel_compute_plan(self, key):
         # Execution is synchronous in the local backend so this
         # function does not make sense.
         raise NotImplementedError
 
     def update_compute_plan(self,
-                            compute_plan_id: str,
+                            key: str,
                             spec: schemas.UpdateComputePlanSpec,
                             spec_options: dict = None):
-        compute_plan = self._db.get(schemas.Type.ComputePlan, compute_plan_id)
+        compute_plan = self._db.get(schemas.Type.ComputePlan, key)
 
         # Get all the new tuples and their dependencies
         (
@@ -990,7 +1011,7 @@ class Local(base.BaseBackend):
         if compute_plan.aggregatetuple_keys:
             for key in compute_plan.aggregatetuple_keys:
                 id_, rank = self.__get_id_rank_in_compute_plan(
-                    schemas.Type.Traintuple,
+                    schemas.Type.Aggregatetuple,
                     key,
                     compute_plan.id_to_key
                 )
@@ -999,7 +1020,7 @@ class Local(base.BaseBackend):
         if compute_plan.composite_traintuple_keys:
             for key in compute_plan.composite_traintuple_keys:
                 id_, rank = self.__get_id_rank_in_compute_plan(
-                    schemas.Type.Traintuple,
+                    schemas.Type.CompositeTraintuple,
                     key,
                     compute_plan.id_to_key
                 )
