@@ -46,8 +46,8 @@ def logit(f):
         finally:
             # add a log even if the function raises an exception
             te = time.time()
-            elaps = (te - ts) * 1000
-            logger.info(f'{f.__name__}: done in {elaps:.2f}ms; error={error}')
+            elapsed = (te - ts) * 1000
+            logger.info(f'{f.__name__}: done in {elapsed:.2f}ms; error={error}')
 
     return wrapper
 
@@ -66,7 +66,7 @@ class Client(object):
         retry_timeout (int, optional): Number of seconds before attempting a retry call in case
             of timeout.
             Defaults to 5 minutes.
-        insecure (bool, optional): If True, the client can call a not-certifed backend. This is
+        insecure (bool, optional): If True, the client can call a not-certified backend. This is
             for development purposes.
             Defaults to False.
         debug (bool, optional): Whether to use the default or debug mode.
@@ -92,7 +92,7 @@ class Client(object):
         self._backend = self._get_backend(debug)
 
     def _get_backend(self, debug: bool):
-        # Three possibilites:
+        # Three possibilities:
         # - debug is False: get a remote backend
         # - debug is True and no url is defined: fully local backend
         # - debug is True and url is defined: local backend that connects to
@@ -190,14 +190,10 @@ class Client(object):
     def add_data_sample(
         self,
         data: Union[dict, schemas.DataSampleSpec],
-        local: bool = True,
-        exist_ok: bool = False
+        local: bool = True
     ) -> str:
         """Create a new data sample asset and return its key.
 
-        If a data sample with the same content already exists, an `AlreadyExists` exception will be
-        raised.
-
         Args:
             data (Union[dict, schemas.DataSampleSpec]): data sample to add. If it is a dict,
                 it must follow the [DataSampleSpec schema](sdk_schemas.md#DataSampleSpec).
@@ -209,8 +205,6 @@ class Client(object):
                 If `local` is false, `path` must refer to a directory located on the server
                 filesystem. This directory must be accessible (readable) by the server.  This
                 mode is well suited for all kind of file sizes. Defaults to True.
-            exist_ok (bool, optional): If `exist_ok` is true, `AlreadyExists` exceptions will
-                be ignored and the existing asset key will be returned. Defaults to False.
 
         Returns:
             str: key of the data sample
@@ -225,7 +219,6 @@ class Client(object):
         }
         return self._backend.add(
             spec,
-            exist_ok=exist_ok,
             spec_options=spec_options
         )
 
@@ -242,9 +235,6 @@ class Client(object):
         large amount of data it is recommended to add them one by one. It allows a
         better control in case of failures.
 
-        If data samples with the same content as any of the paths already exists, an `AlreadyExists`
-        exception will be raised.
-
         Args:
             data (Union[dict, schemas.DataSampleSpec]): data samples to add. If it is a dict,
                 it must follow the [DataSampleSpec schema](sdk_schemas.md#DataSampleSpec).
@@ -266,227 +256,190 @@ class Client(object):
         }
         return self._backend.add(
             spec,
-            exist_ok=False,
             spec_options=spec_options,
         )
 
     @logit
-    def add_dataset(self, data: Union[dict, schemas.DatasetSpec], exist_ok: bool = False):
+    def add_dataset(self, data: Union[dict, schemas.DatasetSpec]):
         """Create new dataset asset and return its key.
 
-        If a dataset with the same opener already exists, an `AlreadyExists` exception will be
-        raised.
+        In debug mode, add the following key: `substra.DEBUG_OWNER` to the metadata,
+        the value becomes the node owner of the data, and all tuples using this data
+        have their worker set to this node. This has no impact on how the tuples are
+        executed except if chainkey support is enabled.
 
         Args:
             data (Union[dict, schemas.DatasetSpec]): If it is a dict, it must have the same
                 keys as specified in [schemas.DatasetSpec](sdk_schemas.md#DatasetSpec).
-            exist_ok (bool, optional): If `exist_ok` is true, `AlreadyExists` exceptions
-                will be ignored and the existing asset key will be returned.
-                Defaults to False.
 
         Returns:
             str: Key of the dataset
         """
         spec = self._get_spec(schemas.DatasetSpec, data)
-        return self._backend.add(spec, exist_ok=exist_ok)
+        return self._backend.add(spec)
 
     @logit
     def add_objective(
         self,
         data: Union[dict, schemas.ObjectiveSpec],
-        exist_ok: bool = False,
     ) -> str:
         """Create new objective asset.
 
-        If an objective with the same description already exists, an `AlreadyExists` exception will
-        be raised.
+        In debug mode, add the following key: `substra.DEBUG_OWNER` to the metadata,
+        the value becomes the 'creator' of the objective.
 
         Args:
             data (Union[dict, schemas.ObjectiveSpec]): If it is a dict, it must have the same keys
                 as specified in [schemas.ObjectiveSpec](sdk_schemas.md#ObjectiveSpec).
-            exist_ok (bool, optional): If `exist_ok` is true, `AlreadyExists` exceptions
-                will be ignored and the existing asset key will be returned. Defaults to False.
 
         Returns:
             str: Key of the objective
         """
         spec = self._get_spec(schemas.ObjectiveSpec, data)
-        return self._backend.add(spec, exist_ok=exist_ok)
+        return self._backend.add(spec)
 
     @logit
-    def add_algo(self, data: Union[dict, schemas.AlgoSpec], exist_ok: bool = False) -> str:
+    def add_algo(self, data: Union[dict, schemas.AlgoSpec]) -> str:
         """Create new algo asset.
 
-        If an algo with the same archive file already exists, an `AlreadyExists` exception will be
-        raised.
+        In debug mode, add the following key: `substra.DEBUG_OWNER` to the metadata,
+        the value becomes the 'creator' of the algo.
 
         Args:
             data (Union[dict, schemas.AlgoSpec]): If it is a dict, it must have the same keys
                 as specified in [schemas.AlgoSpec](sdk_schemas.md#AlgoSpec).
-            exist_ok (bool, optional): If `exist_ok` is true, `AlreadyExists` exceptions will be
-                ignored and the existing asset key will be returned. Defaults to False.
 
         Returns:
             str: Key of the algo
         """
         spec = self._get_spec(schemas.AlgoSpec, data)
-        return self._backend.add(spec, exist_ok=exist_ok)
+        return self._backend.add(spec)
 
     @logit
     def add_aggregate_algo(
         self,
         data: Union[dict, schemas.AggregateAlgoSpec],
-        exist_ok: bool = False,
     ) -> str:
         """Create new aggregate algo asset.
 
-        If an aggregate algo with the same archive file already exists, an `AlreadyExists`
-        exception will be raised.
+        In debug mode, add the following key: `substra.DEBUG_OWNER` to the metadata,
+        the value becomes the 'creator' of the aggregate algo.
 
         Args:
             data (Union[dict, schemas.AggregateAlgoSpec]): If it is a dict,
                 it must have the same keys as specified in
                 [schemas.AggregateAlgoSpec](sdk_schemas.md#AggregateAlgoSpec).
-            exist_ok (bool, optional): If `exist_ok` is true, `AlreadyExists`
-                exceptions will be ignored and the existing asset key will be returned.
-                Defaults to False.
 
         Returns:
             str: Key of the asset
         """
         spec = self._get_spec(schemas.AggregateAlgoSpec, data)
-        return self._backend.add(spec, exist_ok=exist_ok)
+        return self._backend.add(spec)
 
     @logit
     def add_composite_algo(
         self,
-        data: Union[dict, schemas.CompositeAlgoSpec],
-        exist_ok: bool = False
+        data: Union[dict, schemas.CompositeAlgoSpec]
     ) -> str:
         """Create new composite algo asset.
 
-        If a composite algo with the same archive file already exists, an `AlreadyExists`
-        exception will be raised.
+        In debug mode, add the following key: `substra.DEBUG_OWNER` to the metadata,
+        the value becomes the 'creator' of the composite algo.
 
         Args:
             data (Union[dict, schemas.CompositeAlgoSpec]): If it is a dict, it must have the same
                 keys as specified in [schemas.CompositeAlgoSpec](sdk_schemas.md#CompositeAlgoSpec).
-            exist_ok (bool, optional): If `exist_ok` is true, `AlreadyExists`
-                exceptions will be ignored and the existing asset key will be returned.
-                Defaults to False.
 
         Returns:
             str: Key of the asset
         """
         spec = self._get_spec(schemas.CompositeAlgoSpec, data)
-        return self._backend.add(spec, exist_ok=exist_ok)
+        return self._backend.add(spec)
 
     @logit
     def add_traintuple(
         self,
-        data: Union[dict, schemas.TraintupleSpec],
-        exist_ok: bool = False
+        data: Union[dict, schemas.TraintupleSpec]
     ) -> str:
         """Create new traintuple asset.
 
-        An `AlreadyExists` exception will be raised if a traintuple already exists that:
-        * has the same `algo_key`, `data_manager_key`, `train_data_sample_keys` and `in_models_keys`
-        * and was created through the same node you are using
+        In debug mode, add the following key: `substra.DEBUG_OWNER` to the metadata,
+        the value becomes the 'creator' of the traintuple.
 
         Args:
             data (Union[dict, schemas.TraintupleSpec]): If it is a dict, it must have the same
                 keys as specified in [schemas.TraintupleSpec](sdk_schemas.md#TraintupleSpec).
-            exist_ok (bool, optional): If `exist_ok` is true, `AlreadyExists`
-                exceptions will be ignored and the existing asset key will be returned.
-                Defaults to False.
 
         Returns:
             str: Key of the asset
         """
         spec = self._get_spec(schemas.TraintupleSpec, data)
-        return self._backend.add(spec, exist_ok=exist_ok)
+        return self._backend.add(spec)
 
     @logit
     def add_aggregatetuple(
         self,
-        data: Union[dict, schemas.AggregatetupleSpec],
-        exist_ok: bool = False
+        data: Union[dict, schemas.AggregatetupleSpec]
     ) -> str:
         """Create a new aggregate tuple asset.
 
-        An `AlreadyExists` exception will be raised if an aggregatetuple already exists that:
-        * has the same `algo_key` and `in_models_keys`
-        * and was created through the same node you are using
+        In debug mode, add the following key: `substra.DEBUG_OWNER` to the metadata,
+        the value becomes the 'creator' of the aggregate tuple.
 
         Args:
             data (Union[dict, schemas.AggregatetupleSpec]): If it is a dict, it must have the same
                 keys as specified in
                 [schemas.AggregatetupleSpec](sdk_schemas.md#AggregatetupleSpec).
-            exist_ok (bool, optional): If `exist_ok` is true, `AlreadyExists`
-                exceptions will be ignored and the existing asset key will be returned.
-                Defaults to False.
 
         Returns:
             str: Key of the asset
         """
         spec = self._get_spec(schemas.AggregatetupleSpec, data)
-        return self._backend.add(spec, exist_ok=exist_ok)
+        return self._backend.add(spec)
 
     @logit
     def add_composite_traintuple(
         self,
-        data: Union[dict, schemas.CompositeTraintupleSpec],
-        exist_ok: bool = False
+        data: Union[dict, schemas.CompositeTraintupleSpec]
     ) -> str:
         """Create new composite traintuple asset.
 
         As specified in the data structure, output trunk models cannot be made
         public.
 
-        An `AlreadyExists` exception will be raised if a traintuple already exists that:
-        * has the same `algo_key`, `data_manager_key`, `train_data_sample_keys`,
-          `in_head_models_key` and `in_trunk_model_key`
-        * and was created through the same node you are using
+        In debug mode, add the following key: `substra.DEBUG_OWNER` to the metadata,
+        the value becomes the 'creator' of the composite traintuple.
 
         Args:
             data (Union[dict, schemas.CompositeTraintupleSpec]): If it is a dict, it must have the
                 same keys as specified in
                 [schemas.CompositeTraintupleSpec](sdk_schemas.md#CompositeTraintupleSpec).
-            exist_ok (bool, optional): If `exist_ok` is true, `AlreadyExists`
-                exceptions will be ignored and the existing asset key will be returned.
-                Defaults to False.
 
         Returns:
             str: Key of the asset
         """
         spec = self._get_spec(schemas.CompositeTraintupleSpec, data)
-        return self._backend.add(spec, exist_ok=exist_ok)
+        return self._backend.add(spec)
 
     @logit
     def add_testtuple(
         self,
-        data: Union[dict, schemas.TesttupleSpec],
-        exist_ok: bool = False
+        data: Union[dict, schemas.TesttupleSpec]
     ) -> str:
         """Create new testtuple asset.
 
-        An `AlreadyExists` exception will be raised if a testtuple already exists that:
-        * has the same `traintuple_key`, `objective_key`, `data_manager_key` and
-          `test_data_sample_keys`
-        * and was created through the same node you are using
+        In debug mode, add the following key: `substra.DEBUG_OWNER` to the metadata,
+        the value becomes the 'creator' of the testtuple.
 
         Args:
             data (Union[dict, schemas.TesttupleSpec]): If it is a dict, it must have the same
                 keys as specified in [schemas.TesttupleSpec](sdk_schemas.md#TesttupleSpec).
-            exist_ok (bool, optional): If `exist_ok` is true, `AlreadyExists`
-                exceptions will be ignored and the existing asset key will be returned.
-                Defaults to False.
 
         Returns:
             str: Key of the asset
         """
         spec = self._get_spec(schemas.TesttupleSpec, data)
-        return self._backend.add(spec, exist_ok=exist_ok)
+        return self._backend.add(spec)
 
     @logit
     def add_compute_plan(
@@ -506,7 +459,7 @@ class Client(object):
             auto_batching (bool, optional): Set 'auto_batching' to False to upload all the tuples of
                 the compute plan at once. Defaults to True.
             batch_size (int, optional): If 'auto_batching' is True, change `batch_size` to define
-                the number oftuples uploaded in each batch (default 20).
+                the number of tuples uploaded in each batch (default 20).
 
         Returns:
             models.ComputePlan: Created compute plan
@@ -516,7 +469,7 @@ class Client(object):
             "auto_batching": auto_batching,
             "batch_size": batch_size,
         }
-        return self._backend.add(spec, exist_ok=False, spec_options=spec_options)
+        return self._backend.add(spec, spec_options=spec_options)
 
     @logit
     def get_algo(self, key: str) -> models.Algo:
@@ -653,7 +606,7 @@ class Client(object):
     @logit
     def update_compute_plan(
         self,
-        compute_plan_id: str,
+        key: str,
         data: Union[dict, schemas.UpdateComputePlanSpec],
         auto_batching: bool = True,
         batch_size: int = DEFAULT_BATCH_SIZE
@@ -664,7 +617,7 @@ class Client(object):
         traintuples cannot be made public.
 
         Args:
-            compute_plan_id (str): Id of the compute plan
+            key (str): Compute plan key
             data (Union[dict, schemas.UpdateComputePlanSpec]): If it is a dict,
                 it must have the same keys as specified in
                 [schemas.UpdateComputePlanSpec](sdk_schemas.md#UpdateComputePlanSpec).
@@ -683,7 +636,7 @@ class Client(object):
             "batch_size": batch_size,
         }
         return self._backend.update_compute_plan(
-            compute_plan_id,
+            key,
             spec,
             spec_options=spec_options
         )
@@ -799,7 +752,7 @@ class Client(object):
         return self._backend.leaderboard(objective_key, sort='desc')
 
     @logit
-    def cancel_compute_plan(self, compute_plan_id: str) -> models.ComputePlan:
+    def cancel_compute_plan(self, key: str) -> models.ComputePlan:
         """Cancel execution of compute plan, the returned object is described
         in the [models.ComputePlan](sdk_models.md#ComputePlan) model"""
-        return self._backend.cancel_compute_plan(compute_plan_id)
+        return self._backend.cancel_compute_plan(key)
