@@ -77,7 +77,7 @@ class DataSample(_Model):
 
 class _File(schemas._PydanticConfig):
     """File as stored in the models"""
-    hash_: str = pydantic.Field(..., alias="hash")
+    checksum: str
     storage_address: UriPath
 
 
@@ -103,19 +103,15 @@ class _ObjectiveDataset(schemas._PydanticConfig):
     data_manager_key: str
     data_sample_keys: List[str]
     metadata: Dict[str, str]
-    worker: Optional[str]
+    worker: str
 
 
 class _Metric(schemas._PydanticConfig):
     """Metric associated to a testtuple or objective"""
     name: Optional[str]
-    hash_: str = pydantic.Field(..., alias="hash")
+    checksum: str
     storage_address: UriPath
 
-    @property
-    def key(self):
-        return self.hash_
-
 
 class Objective(_Model):
     """Objective"""
@@ -160,49 +156,37 @@ class CompositeAlgo(_Algo):
 
 class _TraintupleDataset(schemas._PydanticConfig):
     """Dataset as stored in a traintuple or composite traintuple"""
-    opener_hash: str
-    keys: List[str]
+    key: str
+    opener_checksum: str
+    data_sample_keys: List[str]
     worker: str
     metadata: Optional[Dict[str, str]]
 
-    @property
-    def key(self):
-        return self.opener_hash
-
 
 class InModel(schemas._PydanticConfig):
     """In model of a traintuple, aggregate tuple or in trunk
     model of a composite traintuple"""
-    hash_: str = pydantic.Field(..., alias="hash")
+    key: str
+    checksum: str
     storage_address: UriPath
     traintuple_key: Optional[str]
 
-    @property
-    def key(self):
-        return self.hash_
-
 
 class OutModel(schemas._PydanticConfig):
     """Out model of a traintuple, aggregate tuple or out trunk
     model of a composite traintuple"""
-    hash_: str = pydantic.Field(..., alias="hash")
+    key: str
+    checksum: str
     storage_address: UriPath
 
-    @property
-    def key(self):
-        return self.hash_
-
 
 class _TraintupleAlgo(schemas._PydanticConfig):
     """Algo associated to a traintuple"""
-    hash_: str = pydantic.Field(..., alias="hash")
+    key: str
+    checksum: str
     storage_address: UriPath
     name: str
 
-    @property
-    def key(self):
-        return self.hash_
-
 
 class Traintuple(_Model):
     """Traintuple"""
@@ -212,7 +196,7 @@ class Traintuple(_Model):
     dataset: _TraintupleDataset
     permissions: Permissions
     tag: str
-    compute_plan_id: str
+    compute_plan_key: str
     rank: int
     status: str
     log: str
@@ -232,7 +216,7 @@ class Aggregatetuple(_Model):
     algo: _TraintupleAlgo
     permissions: Permissions
     tag: str
-    compute_plan_id: str
+    compute_plan_key: str
     rank: Optional[int]
     status: str
     log: str
@@ -246,24 +230,18 @@ class Aggregatetuple(_Model):
 
 class InHeadModel(schemas._PydanticConfig):
     """In head model of a composite traintuple"""
-    hash_: str = pydantic.Field(..., alias="hash")
+    key: str
+    checksum: str
     storage_address: Optional[UriPath]  # Defined for local assets but not remote ones
     traintuple_key: Optional[str]
 
-    @property
-    def key(self):
-        return self.hash_
-
 
 class OutHeadModel(schemas._PydanticConfig):
     """Out head model of a composite traintuple"""
-    hash_: str = pydantic.Field(..., alias="hash")
+    key: str
+    checksum: str
     storage_address: Optional[FilePath]  # Defined for local assets but not remote ones
 
-    @property
-    def key(self):
-        return self.hash_
-
 
 class OutCompositeHeadModel(schemas._PydanticConfig):
     """Out head model of a composite traintuple with permissions"""
@@ -284,7 +262,7 @@ class CompositeTraintuple(_Model):
     algo: _TraintupleAlgo
     dataset: _TraintupleDataset
     tag: str
-    compute_plan_id: str
+    compute_plan_key: str
     rank: Optional[int]
     status: str
     log: str
@@ -302,25 +280,18 @@ class CompositeTraintuple(_Model):
 
 class _TesttupleDataset(schemas._PydanticConfig):
     """Dataset of a testtuple"""
-    opener_hash: str
+    key: str
+    opener_checksum: str
     perf: float
-    keys: List[str]
+    data_sample_keys: List[str]
     worker: str
 
-    @property
-    def key(self):
-        return self.opener_hash
-
 
 class _TesttupleObjective(schemas._PydanticConfig):
     """Objective of a testtuple"""
-    hash_: str = pydantic.Field(..., alias="hash")
+    key: str
     metrics: _Metric
 
-    @property
-    def key(self):
-        return self.hash_
-
 
 class Testtuple(_Model):
     """Testtuple"""
@@ -334,7 +305,7 @@ class Testtuple(_Model):
     tag: Optional[str]
     log: str
     status: str
-    compute_plan_id: str
+    compute_plan_key: str
     rank: int
     traintuple_type: schemas.Type
     metadata: Dict[str, str]
@@ -348,7 +319,7 @@ class Testtuple(_Model):
 
 class ComputePlan(_Model):
     """ComputePlan"""
-    compute_plan_id: str
+    key: str
     status: str
     traintuple_keys: Optional[List[str]]
     composite_traintuple_keys: Optional[List[str]]
@@ -364,7 +335,7 @@ class ComputePlan(_Model):
     type_: ClassVar[str] = schemas.Type.ComputePlan
 
     def __str__(self):
-        return f"{self.__class__.type_.value}(key={self.compute_plan_id})"
+        return f"{self.__class__.type_.value}(key={self.key})"
 
 
 class Node(schemas._PydanticConfig):
