@@ -23,7 +23,7 @@ import uuid
 
 import pydantic
 
-from substra.sdk import utils, fs, hasher
+from substra.sdk import utils
 
 # TODO create a sub-package schemas:
 # types
@@ -87,8 +87,9 @@ class _Spec(_PydanticConfig, abc.ABC):
         else:
             yield data, None
 
+    @staticmethod
     def compute_key() -> str:
-        raise NotImplementedError
+        return str(uuid.uuid4())
 
 
 class Permissions(_PydanticConfig):
@@ -141,9 +142,6 @@ class DataSampleSpec(_Spec):
         else:
             yield data, None
 
-    def compute_key(self) -> str:
-        return fs.hash_directory(self.path)
-
 
 class ComputePlanTraintupleSpec(_Spec):
     """Specification of a traintuple inside a compute
@@ -208,10 +206,6 @@ class ComputePlanSpec(_BaseComputePlanSpec):
 
     type_: typing.ClassVar[Type] = Type.ComputePlan
 
-    @staticmethod
-    def compute_key() -> str:
-        return uuid.uuid4().hex
-
 
 class UpdateComputePlanSpec(_BaseComputePlanSpec):
     """Specification for updating a compute plan"""
@@ -233,9 +227,6 @@ class DatasetSpec(_Spec):
     class Meta:
         file_attributes = ('data_opener', 'description', )
 
-    def compute_key(self) -> str:
-        return fs.hash_file(self.data_opener)
-
 
 class ObjectiveSpec(_Spec):
     """Specification for creating an objective"""
@@ -253,9 +244,6 @@ class ObjectiveSpec(_Spec):
     class Meta:
         file_attributes = ('metrics', 'description', )
 
-    def compute_key(self) -> str:
-        return fs.hash_file(self.metrics)
-
 
 class _AlgoSpec(_Spec):
     name: str
@@ -267,9 +255,6 @@ class _AlgoSpec(_Spec):
     class Meta:
         file_attributes = ('file', 'description', )
 
-    def compute_key(self) -> str:
-        return fs.hash_file(self.file)
-
 
 class AlgoSpec(_AlgoSpec):
     """Specification for creating an algo"""
@@ -293,7 +278,7 @@ class TraintupleSpec(_Spec):
     train_data_sample_keys: List[str]
     in_models_keys: Optional[List[str]]
     tag: Optional[str]
-    compute_plan_id: Optional[str]
+    compute_plan_key: Optional[str]
     rank: Optional[int]  # Rank of the traintuple in the compute plan
     metadata: Optional[Dict[str, str]]
 
@@ -304,7 +289,7 @@ class TraintupleSpec(_Spec):
     @classmethod
     def from_compute_plan(
         cls,
-        compute_plan_id: str,
+        compute_plan_key: str,
         id_to_key: typing.Dict[str, str],
         rank: int,
         spec: ComputePlanTraintupleSpec
@@ -317,19 +302,11 @@ class TraintupleSpec(_Spec):
                 id_to_key[parent_id] for parent_id in spec.in_models_ids
             ],
             tag=spec.tag,
-            compute_plan_id=compute_plan_id,
+            compute_plan_key=compute_plan_key,
             rank=rank,
             metadata=spec.metadata
         )
 
-    def compute_key(self) -> str:
-        key_components = (
-            [self.algo_key, self.data_manager_key]
-            + self.train_data_sample_keys
-            + (self.in_models_keys or list())
-        )
-        return hasher.Hasher(values=key_components).compute()
-
 
 class AggregatetupleSpec(_Spec):
     """Specification for creating an aggregate tuple"""
@@ -337,7 +314,7 @@ class AggregatetupleSpec(_Spec):
     worker: str
     in_models_keys: List[str]
     tag: Optional[str]
-    compute_plan_id: Optional[str]
+    compute_plan_key: Optional[str]
     rank: Optional[int]
     metadata: Optional[Dict[str, str]]
 
@@ -348,7 +325,7 @@ class AggregatetupleSpec(_Spec):
     @classmethod
     def from_compute_plan(
         cls,
-        compute_plan_id: str,
+        compute_plan_key: str,
         id_to_key: typing.Dict[str, str],
         rank: int,
         spec: ComputePlanAggregatetupleSpec
@@ -361,15 +338,11 @@ class AggregatetupleSpec(_Spec):
                 for parent_id in spec.in_models_ids
             ],
             tag=spec.tag,
-            compute_plan_id=compute_plan_id,
+            compute_plan_key=compute_plan_key,
             rank=rank,
             metadata=spec.metadata
         )
 
-    def compute_key(self) -> str:
-        key_components = self.in_models_keys + [self.algo_key]
-        return hasher.Hasher(values=key_components).compute()
-
 
 class CompositeTraintupleSpec(_Spec):
     """Specification for creating a composite traintuple"""
@@ -379,7 +352,7 @@ class CompositeTraintupleSpec(_Spec):
     in_head_model_key: Optional[str]
     in_trunk_model_key: Optional[str]
     tag: Optional[str]
-    compute_plan_id: Optional[str]
+    compute_plan_key: Optional[str]
     out_trunk_model_permissions: PrivatePermissions
     rank: Optional[int]
     metadata: Optional[Dict[str, str]]
@@ -390,7 +363,7 @@ class CompositeTraintupleSpec(_Spec):
     @classmethod
     def from_compute_plan(
         cls,
-        compute_plan_id: str,
+        compute_plan_key: str,
         id_to_key: typing.Dict[str, str],
         rank: int,
         spec: ComputePlanCompositeTraintupleSpec
@@ -407,19 +380,11 @@ class CompositeTraintupleSpec(_Spec):
                 "authorized_ids": spec.out_trunk_model_permissions.authorized_ids
             },
             tag=spec.tag,
-            compute_plan_id=compute_plan_id,
+            compute_plan_key=compute_plan_key,
             rank=rank,
             metadata=spec.metadata
         )
 
-    def compute_key(self) -> str:
-        key_components = [self.algo_key, self.data_manager_key] + self.train_data_sample_keys
-        if self.in_head_model_key:
-            key_components.append(self.in_head_model_key)
-        if self.in_trunk_model_key:
-            key_components.append(self.in_trunk_model_key)
-        return hasher.Hasher(values=key_components).compute()
-
 
 class TesttupleSpec(_Spec):
     """Specification for creating a testtuple"""
@@ -446,9 +411,3 @@ class TesttupleSpec(_Spec):
             test_data_sample_keys=spec.test_data_sample_keys,
             metadata=spec.metadata,
         )
-
-    def compute_key(self) -> str:
-        key_components = [self.objective_key, self.traintuple_key]
-        key_components += self.test_data_sample_keys or list()
-        key_components += self.data_manager_key or list()
-        return hasher.Hasher(values=key_components).compute()
