@@ -104,25 +104,25 @@ def test_command_login(workdir, mocker):
     m.assert_called()
 
 
-@pytest.mark.parametrize('asset_name,key_field,model', [
-    ('objective', 'key', models.Objective),
-    ('dataset', 'key', models.Dataset),
-    ('algo', 'key', models.Algo),
-    ('aggregate_algo', 'key', models.AggregateAlgo),
-    ('composite_algo', 'key', models.CompositeAlgo),
-    ('testtuple', 'key', models.Testtuple),
-    ('traintuple', 'key', models.Traintuple),
-    ('aggregatetuple', 'key', models.Aggregatetuple),
-    ('composite_traintuple', 'key', models.CompositeTraintuple),
-    ('compute_plan', 'compute_plan_id', models.ComputePlan),
+@pytest.mark.parametrize('asset_name,model', [
+    ('objective', models.Objective),
+    ('dataset', models.Dataset),
+    ('algo', models.Algo),
+    ('aggregate_algo', models.AggregateAlgo),
+    ('composite_algo', models.CompositeAlgo),
+    ('testtuple', models.Testtuple),
+    ('traintuple', models.Traintuple),
+    ('aggregatetuple', models.Aggregatetuple),
+    ('composite_traintuple', models.CompositeTraintuple),
+    ('compute_plan', models.ComputePlan),
 ])
-def test_command_list(asset_name, key_field, model, workdir, mocker):
+def test_command_list(asset_name, model, workdir, mocker):
     item = model(**getattr(datastore, asset_name.upper()))
     method_name = f'list_{asset_name}'
     m = mock_client_call(mocker, method_name, [item])
     output = client_execute(workdir, ['list', asset_name])
     m.assert_called()
-    assert getattr(item, key_field) in output
+    assert item.key in output
 
 
 def test_command_list_node(workdir, mocker):
@@ -276,27 +276,6 @@ def test_command_add_data_sample(workdir, mocker):
     assert re.search(r"Directory '.*' does not exist\.", res)
 
 
-@pytest.mark.parametrize('asset_name, params', [
-    ('dataset', []),
-    ('algo', []),
-    ('traintuple', ['--algo-key', 'foo', '--dataset-key', 'foo',
-                    '--data-samples-path']),
-    ('testtuple', ['--objective-key', 'foo', '--traintuple-key', 'foo', '--data-samples-path']),
-    ('compute_plan', []),
-    ('objective', []),
-])
-def test_command_add_already_exists(workdir, mocker, asset_name, params):
-    m = mock_client_call(mocker, f'add_{asset_name}',
-                         side_effect=substra.exceptions.AlreadyExists('foo', 409))
-    json_file = workdir / "valid_json_file.json"
-    json_file.write_text(json.dumps({}))
-    output = client_execute(workdir, ['add', asset_name] + params + [str(json_file)],
-                            exit_code=1)
-
-    assert 'already exists' in output
-    m.assert_called()
-
-
 def test_command_add_data_sample_already_exists(workdir, mocker):
     m = mock_client_call(mocker, 'add_data_samples',
                          side_effect=substra.exceptions.AlreadyExists('foo', 409))
@@ -304,29 +283,29 @@ def test_command_add_data_sample_already_exists(workdir, mocker):
     temp_dir.mkdir()
     output = client_execute(workdir, ['add', 'data_sample', str(temp_dir), '--dataset-key', 'foo'],
                             exit_code=1)
-    assert 'already exists' in output
+    assert 'already exist' in output
     m.assert_called()
 
 
-@pytest.mark.parametrize('asset_name,key_field,model', [
-    ('objective', 'key', models.Objective),
-    ('dataset', 'key', models.Dataset),
-    ('algo', 'key', models.Algo),
-    ('aggregate_algo', 'key', models.AggregateAlgo),
-    ('composite_algo', 'key', models.CompositeAlgo),
-    ('testtuple', 'key', models.Testtuple),
-    ('traintuple', 'key', models.Traintuple),
-    ('aggregatetuple', 'key', models.Aggregatetuple),
-    ('composite_traintuple', 'key', models.CompositeTraintuple),
-    ('compute_plan', 'compute_plan_id', models.ComputePlan),
+@pytest.mark.parametrize('asset_name,model', [
+    ('objective', models.Objective),
+    ('dataset', models.Dataset),
+    ('algo', models.Algo),
+    ('aggregate_algo', models.AggregateAlgo),
+    ('composite_algo', models.CompositeAlgo),
+    ('testtuple', models.Testtuple),
+    ('traintuple', models.Traintuple),
+    ('aggregatetuple', models.Aggregatetuple),
+    ('composite_traintuple', models.CompositeTraintuple),
+    ('compute_plan', models.ComputePlan),
 ])
-def test_command_get(asset_name, key_field, model, workdir, mocker):
+def test_command_get(asset_name, model, workdir, mocker):
     item = model(**getattr(datastore, asset_name.upper()))
     method_name = f'get_{asset_name}'
     m = mock_client_call(mocker, method_name, item)
     output = client_execute(workdir, ['get', asset_name, 'fakekey'])
     m.assert_called()
-    assert getattr(item, key_field) in output
+    assert item.key in output
 
 
 def test_command_describe(workdir, mocker):
